FROM git.shihaam.dev/dockerfiles/php-fpm:8.3

LABEL maintainer="Shiham Abdul Rahman <shihaam@shihaam.me>"
LABEL org.opencontainers.image.source="https://git.shihaam.dev/dockerfiles/nextcloud"
LABEL org.opencontainers.image.documentation="https://git.shihaam.dev/dockerfiles/nextcloud"
LABEL org.opencontainers.image.description="A simplified docker image for nextcloud"

ARG URL=https://download.nextcloud.com/server/releases/
ARG VERSION
WORKDIR /var/www/html
SHELL ["/bin/bash", "-c"]

# Download, Extract and Delete nextcloud tar.bz2
RUN curl ${URL}nextcloud-${VERSION}.tar.bz2 -o nextcloud-${VERSION}.tar.bz2 \
 && tar -vxjf nextcloud-${VERSION}.tar.bz2 \
 && mv -v nextcloud/* . \
 && rm -rv nextcloud nextcloud-${VERSION}.tar.bz2

# Installing basic tools
RUN apt-get update && apt-get install bzip2 zip unzip git gnupg2 ca-certificates lsb-release apt-transport-https wget curl nano vim -y --no-install-recommends \
 && apt-get auto-remove -y \
 && apt-get clean -y

# Copy php.ini config
COPY php.ini /usr/local/etc/php/php.ini

# Install Php stuff
RUN docker-php-ext-install {gd,mysqli,pdo,pdo_mysql,bcmath,calendar,zip,gettext,exif,pcntl,shmop,-j$(nproc),gd,sysvmsg,sysvsem,sysvshm}

# export volume for nginx to serve static files
VOLUME /var/www/html
